#[repr(C)]pub struct Rpc<T: DeserializeOwned + Debug> {
pub json_rpc: &'static str,
pub method: String,
pub params: Vec<Value>,
pub id: usize,
pub result_type: PhantomData<T>,
}Expand description
Wrapper for the remote procedure call
This is usually not directly needed and returned by the functions which wrap the different namespaces. However, it is also possible to create custom Rpc structs.
Fields
json_rpc: &'static strThe version of the JSON RPC spec
method: StringThe method which is called
params: Vec<Value>Arguments supplied to the method. Can be an empty Vec.
id: usizeThe id for the request
result_type: PhantomData<T>Type annotation needed for the result